@@ -2,6 +2,7 @@ from jupyter_server.utils import url_path_join
 from tornado import ioloop
 
 from jupyter_resource_usage.api import ApiHandler
+from jupyter_resource_usage.api import KernelUsageHandler
 from jupyter_resource_usage.config import ResourceUseDisplay
 from jupyter_resource_usage.metrics import PSUtilMetricsLoader
 from jupyter_resource_usage.prometheus import PrometheusHandler
@@ -18,6 +19,17 @@ def load_jupyter_server_extension(server_app):
     server_app.web_app.add_handlers(
         ".*", [(url_path_join(base_url, "/api/metrics/v1"), ApiHandler)]
     )
+    server_app.web_app.add_handlers(
+        ".*$",
+        [
+            (
+                url_path_join(
+                    base_url, "/api/metrics/v1/kernel_usage", r"get_usage/(.+)$"
+                ),
+                KernelUsageHandler,
+            )
+        ],
+    )
 
     if resuseconfig.enable_prometheus_metrics:
         callback = ioloop.PeriodicCallback(
